# $Id: $

package FarmAgent;
use strict;

my (@agents) = ('Mozilla/4.0 (compatible; MSIE 4.01; AOL 4.0; Windows 95)',
	'Mozilla/4.0 (compatible; MSIE 4.01; AOL 6.0;TargetAOL6.0; Windows 98)',
	'Mozilla/4.0 (compatible; MSIE 4.01; MSN 2.5; Windows 98)',
	'Mozilla/4.0 (compatible; MSIE 5.0; AOL 6.0; Windows 98; DigExt)',
	'Mozilla/4.0 (compatible; MSIE 5.01; Windows 98)',
	'Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)',
	'Mozilla/4.0 (compatible; MSIE 5.01; Windows 98; AT&T CSM6.0)',
	'Mozilla/4.0 (compatible; MSIE 5.5; AOL 5.0; Windows 98; Win 9x 4.90)',
	'Mozilla/4.0 (compatible; MSIE 5.5; Windows 98; Win 9x 4.90)',
	'Mozilla/4.0 (compatible; MSIE 5.5; Windows 98)');

#	'Mozilla/4.0 (compatible; MSIE 5.0; Mac_PowerPC)',


sub agent {
	return $agents[rand(scalar(@agents))];

}


1;
